package com.tomwheeler.stocktrader.api.events;

/**
 * <p>
 * This class stores data associated with a change to a StockAccount.
 * </p> 
 * 
 * @author Tom Wheeler
 */
public class StockAccountChangeEvent extends AbstractChangeEvent {
    
    // I'd rather use built-in enum types for Java5, but maybe some users
    // don't have Java5 yet.  Writing a type-safe enum class is too much work
    // for this.
    public static final int STOCKS_PURCHASED = 1;
    public static final int STOCKS_SOLD = 2;

    private String symbol;
    private int eventType;

    /**
     * <p> 
     * Creates a new StockAccountChangeEvent with the specified description.  The
     * symbol, if available, should be set with the setSymbol(java.lang.String)
     * method.
     * </p>
     * 
     * @param changeDescription the description of the change
     * @throws IllegalArgumentException if the event type is invalid
     * @see setSymbol(java.lang.String)
     */
    public StockAccountChangeEvent(String changeDescription, int eventType, String symbol) {       
        super(changeDescription);

        if (eventType != STOCKS_PURCHASED && eventType != STOCKS_SOLD) {
            throw new IllegalArgumentException("Invalid Event Type");
        }

        this.symbol = symbol;
        this.eventType = eventType;
    }

    /** @return the symbol associated with this change, if available */ 
    public String getSymbol() {
        return symbol;
    }
    
    /** @return the type of event; either STOCKS_PURCHASED or STOCKS_SOLD */ 
    public int getEventType() {
        return eventType;
    }
}
