/*
 *                 Sun Public License Notice
 * 
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 * 
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Sun Microsystems, Inc. Portions Copyright 1997-2005 Sun
 * Microsystems, Inc. All Rights Reserved.
 */
package com.tomwheeler.stocktrader.ui.gamectrl;

import java.awt.BorderLayout;
import java.io.ObjectStreamException;

import org.openide.ErrorManager;
import org.openide.util.*;
import org.openide.windows.*;

import com.tomwheeler.stocktrader.api.Game;

/**
 * <p>
 * This class provides a TopComponent for integrating the game controller
 * component with NetBeans.
 * </p> 
 * 
 * @author Tom Wheeler
 */
public class GameControllerTopComponent extends TopComponent {

    private static final String PREFERRED_ID = "gamectrl";
    private static String s_id = PREFERRED_ID;
    private static final String MODE = "explorer";
    
    /* (non-Javadoc)
     * @see org.openide.util.HelpCtx$Provider#getHelpCtx()
     */
    public HelpCtx getHelpCtx() {
        return HelpCtx.DEFAULT_HELP;
    }

    public GameControllerTopComponent() {
        super();
        setLayout(new BorderLayout());
        setDisplayName(NbBundle.getMessage(GameControllerTopComponent.class,
                "LBL_GameControllerTopComponent_DisplayName"));
        setIcon(Utilities.loadImage("com/tomwheeler/stocktrader/ui/resources/controller-icon.gif"));
        
        Lookup lookup = Lookup.getDefault();
        Game game = (Game)lookup.lookup(Game.class);
        if (game == null) {
            // this will show up as a flashing round button in the bottom-right corner
            ErrorManager.getDefault().notify(
                    new IllegalStateException("Cannot locate Game implementation"));
        }

        // the actual UI code is in this class
        add(new GameControllerComponent(game), BorderLayout.CENTER);
    }

    public static synchronized void activate() {
        TopComponent tc = getInstance();
        tc.open();
        tc.requestActive();
    }

    public static synchronized GameControllerTopComponent getInstance() {
        TopComponent tc = WindowManager.getDefault().findTopComponent(s_id);
        if (tc == null) {
            tc = new GameControllerTopComponent();
            s_id = WindowManager.getDefault().findTopComponentID(tc);
        }
        return (GameControllerTopComponent) tc;
    }
   
    /* (non-Javadoc)
     * @see org.openide.windows.TopComponent#open()
     */
    public void open() {
        Mode mode = WindowManager.getDefault().findMode(MODE);
        if (mode != null) {
            mode.dockInto(this);
        }
                                                                                                                   
        super.open();
    }
                                                                                                                   
    /* (non-Javadoc)
     * @see org.openide.windows.TopComponent#preferredID()
     */
    protected String preferredID() {
        return PREFERRED_ID;
    }

    /* (non-Javadoc)
     * @see org.openide.windows.TopComponent#getPersistenceType()
     */
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_ONLY_OPENED;
    }

    /**
     * <p>
     * We must implement this method to enforce that this TopComponent is 
     * a singleton.  If we didn't, then we'd get a different copy when the
     * old one is deserialized by the window system.
     * </p>  
     */
    public Object readResolve() throws ObjectStreamException {
        return getInstance();
    }
}
